#!/bin/bash
# This script is licensed under your favorite open source license.
# I really don't care what you do with it.

if [ $# -ne 4 ]; then
	echo "Usage: build.sh [architecture] [package version] [normal|sdk] [binary tar.gz url]"
	echo "Note: It is recommended to use \`fakeroot build.sh ...\` to ensure correct file permissions"
	echo -e "Example usage:\n\tfakeroot ./build.sh amd64 0.38.4 normal https://dl.nwjs.io/v0.38.4/nwjs-v0.38.4-linux-x64.tar.gz"
	exit 1
fi

ARCH=$1
VERSION=$2
TYPE=$3
URL=$4
FILENAME="nwjs-$TYPE_$VERSION-1_$ARCH.deb"

mkdir -p out

# Fill in real architecture and version info
# Need to escape periods in the version string first
ESCAPEDVERSION=$(echo "$VERSION" | sed 's/\./\\\./g')
echo "Setting package version, architecture, and type in control file"
sed -i "s/ARCH/$ARCH/" debian/DEBIAN/control
sed -i "s/VERSION/$ESCAPEDVERSION/" debian/DEBIAN/control

if [ $TYPE == "sdk" ]; then
	sed -i "s/sdk/SDK/" debian/DEBIAN/control
	sed -i "s/normal/sdk/" debian/DEBIAN/control
	sed -i "s/SDK/normal/" debian/DEBIAN/control
fi

function clean_exit() {
	echo "Resetting arch/version strings in control file"
	sed -i "s/$ARCH/ARCH/" debian/DEBIAN/control
	sed -i "s/$ESCAPEDVERSION/VERSION/" debian/DEBIAN/control
	if [ $TYPE == "sdk" ]; then
		sed -i "s/sdk/SDK/" debian/DEBIAN/control
		sed -i "s/normal/sdk/" debian/DEBIAN/control
		sed -i "s/SDK/normal/" debian/DEBIAN/control
	fi
	exit 0
}

# Clean and remake binary folder
rm -rf debian/usr/lib/nw.js
mkdir -p debian/usr/lib/nw.js

# Make sure the control file resets even when Ctrl-C pressed
trap "clean_exit" 2

# Download binary
echo "Downloading and unpacking $URL"
wget -q -O- $URL | tar -xvz --strip 1 -C debian/usr/lib/nw.js

echo "Packaging deb file"
dpkg-deb -b debian "out/$FILENAME"

clean_exit
